## Description

A pattern for a sticky polyfill.

## Documentation

This pattern provides a sticky polyfill. It

- supports top-positioned stickies,
- works in IE9+,
- disables in older IEs and in browsers with native position: sticky support.
- Mimics original position: sticky behavior

What it doesn't:

- doesn't support left, right, bottom or combined stickies,
- doesn't work in overflowed blocks,

### Examples



### What library is currently used?

This pattern uses Stickyfill (https://github.com/wilddeer/stickyfill).



### Option reference

There are no options.
